@@ -4,7 +4,7 @@ package PONAPI::Server;
 use strict;
 use warnings;
 
-our $VERSION = '0.002007';
+our $VERSION = '0.002008';
 
 use Plack::Request;
 use Plack::Response;
@@ -39,7 +39,9 @@ sub prepare_app {
     my %conf;
     local $@;
     eval {
-        %conf = PONAPI::Server::ConfigReader->new( dir => 'conf' )->read_config;
+        %conf = PONAPI::Server::ConfigReader->new(
+            dir => $self->{'ponapi.config_dir'} || 'conf'
+        )->read_config;
     };
     $self->{$_} //= $conf{$_} for keys %conf;
 
@@ -354,7 +356,7 @@ PONAPI::Server - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/
 
 =head1 VERSION
 
-version 0.002007
+version 0.002008
 
 =head1 SYNOPSIS
 
